#
# spec file for package libyubikey
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         sover 0
Name:           libyubikey
Version:        1.13
Release:        3.25
Summary:        Yubico's USB key low-level C library
License:        BSD-2-Clause
Group:          Productivity/Networking/Security
Url:            https://developers.yubico.com/
# a different tarball is available from github.  It will not build with this spec file
Source0:        https://developers.yubico.com/yubico-c/Releases/%{name}-%{version}.tar.gz
Source1:        https://developers.yubico.com/yubico-c/Releases/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring

%description
Low-level library for decrypting and parsing Yubikey One-Time Passwords
(OTP) in C.

%package -n %{name}%{sover}
Summary:        Yubico's USB key low-level C library
Group:          Productivity/Networking/Security

%description -n %{name}%{sover}
Low-level library for decrypting and parsing Yubikey One-Time Passwords
(OTP) in C.

%package        devel
Summary:        Yubico's USB key low-level C library
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}
Requires:       glibc-devel

%description devel
Low-level library for decrypting and parsing Yubikey One-Time Passwords
(OTP) in C.

%package        tools
Summary:        Tools to support Yubico's USB key low-level C library
Group:          Development/Libraries/C and C++

%description tools
Binary tools to support Yubico's Low-level library for decrypting and
parsing Yubikey One-Time Passwords (OTP) in C.

%prep
%setup -q

%build
%configure \
  --disable-silent-rules \
  --disable-static
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
# path needs to be exported otherwise unit tests will fail
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
make %{?_smp_mflags} check

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files tools
%defattr(-,root,root,-)
%doc COPYING AUTHORS NEWS
%{_bindir}/modhex
%{_bindir}/ykgenerate
%{_bindir}/ykparse
%{_mandir}/man1/modhex.1%{ext_man}
%{_mandir}/man1/ykgenerate.1%{ext_man}
%{_mandir}/man1/ykparse.1%{ext_man}

%files -n %{name}%{sover}
%defattr(-,root,root,-)
%doc COPYING AUTHORS NEWS
%{_libdir}/libyubikey.so.%{sover}*

%files devel
%defattr(-,root,root,-)
%doc COPYING AUTHORS NEWS
%{_libdir}/libyubikey.so
%{_includedir}/yubikey.h

%changelog
* Mon Jun 26 2017 mpluskal@suse.com
- Add gpg signature
- Make building more verbose
- Enable internal testsuite
* Wed Apr 15 2015 jengelh@inai.de
- Cleanup: --with-pic is useless because no static libs are built.
  Remove stray leading newline in description.
* Wed Apr  1 2015 meissner@suse.com
- add COPYING AUTHORS NEWS to shipped packages (COPYING as legal req)
* Thu Mar  5 2015 t.gruner@katodev.de
- Version 1.13 (released 2015-03-05)
  - Correct hex decode with uneven characters, for example "abc".
* Sat Jan 10 2015 Greg.Freemyer@gmail.com
- spec file clean up
  - change URL: to point to developers.yubico.com
  - change Source: to point to new developers.yubico.com download
  - ran spec-cleaner
- create a new sub-package (-tools) for binary executables
  - contains modhex, ykgenerate, ykparse, %%{_mandir}/man1/*
* Fri Oct  3 2014 mmarek@suse.cz
- Updated to version 1.12
  - minor bug and warning fixes, added manpages
- Dropped patch: libyubikey-1.7-rpath-and-auto.patch
- Fix package license
* Fri Jan 28 2011 cristian.rodriguez@opensuse.org
- Initial package, version 1.7
